@@ -55,7 +55,7 @@ bool StationDatabase::loadStation( const QString & stationID )
 	while ( !stream.atEnd() )
 	{
 		line = stream.readLine(); // line of text excluding '\n'
-		QStringList data = line.split( ";", QString::KeepEmptyParts);
+		QStringList data = line.split( ';', QString::KeepEmptyParts);
 
 		if ( data[ 0 ].trimmed() == stationID )
 		{
